==> pyExtendedConfigParser-1.0.2.tar.gz: pyExtendedConfigParser-1.0.2/README.md <==
![PyPI - License](https://img.shields.io/pypi/l/pyExtendedConfigParser)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/Paebbels/pyExtendedConfigParser) 
![GitHub release (latest by date)](https://img.shields.io/github/v/release/Paebbels/pyExtendedConfigParser)
[![Documentation Status](https://readthedocs.org/projects/pyextendedconfigparser/badge/?version=latest)](https://pyextendedconfigparser.readthedocs.io/en/latest/?badge=latest)  
[![PyPI](https://img.shields.io/pypi/v/pyExtendedConfigParser)](https://pypi.org/project/pyExtendedConfigParser/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyExtendedConfigParser)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/pyExtendedConfigParser)
![PyPI - Status](https://img.shields.io/pypi/status/pyExtendedConfigParser)

# ExtendedConfigParser

<!--
[[![Build Status](https://travis-ci.org/Paebbels/ExtendedConfigParser.svg?branch=master)](https://travis-ci.org/Paebbels/ExtendedConfigParser)](https://travis-ci.org/Paebbels/ExtendedConfigParser/branches)
-->


This is an extension and improvement for Pythons [ConfigParser](https://docs.python.org/3/library/configparser.html).

## 1 Overview


### Improvements

 -  Faster interpolation
 -  Interpolation cache
 -  Section name interpolation
 -  Multiple DEFAULT sections
 -  Nested interpolation

## 2 Interpolations

### 2.1 Option interpolation

### 2.2 Section:Option interpolation

### 2.3 Section interpolation


## 3 Short Example

```ini
[section1]
option11 = value11
option12 = value12
option13 = value13

[section2]
option21 = value21
option22 = value22
```

## Contributors:

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)


## License

This library is licensed under [Apache License 2.0](LICENSE.md)

-------------------------

SPDX-License-Identifier: Apache-2.0

==> pyExtendedConfigParser-1.1.1.tar.gz: pyExtendedConfigParser-1.1.1/README.md <==
![PyPI - License](https://img.shields.io/pypi/l/pyExtendedConfigParser)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/Paebbels/pyExtendedConfigParser) 
![GitHub release (latest by date)](https://img.shields.io/github/v/release/Paebbels/pyExtendedConfigParser)
[![Documentation Status](https://readthedocs.org/projects/pyextendedconfigparser/badge/?version=latest)](https://pyextendedconfigparser.readthedocs.io/en/latest/?badge=latest)  
[![PyPI](https://img.shields.io/pypi/v/pyExtendedConfigParser)](https://pypi.org/project/pyExtendedConfigParser/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyExtendedConfigParser)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/pyExtendedConfigParser)
![PyPI - Status](https://img.shields.io/pypi/status/pyExtendedConfigParser)

# pyExtendedConfigParser

<!--
[[![Build Status](https://travis-ci.org/Paebbels/ExtendedConfigParser.svg?branch=master)](https://travis-ci.org/Paebbels/ExtendedConfigParser)](https://travis-ci.org/Paebbels/ExtendedConfigParser/branches)
-->


This is an extension and improvement for Pythons [ConfigParser](https://docs.python.org/3/library/configparser.html).

## 1 Overview


### Improvements

 -  Faster interpolation
 -  Interpolation cache
 -  Section name interpolation
 -  Multiple DEFAULT sections
 -  Nested interpolation

## 2 Interpolations

### 2.1 Option interpolation

### 2.2 Section:Option interpolation

### 2.3 Section interpolation


## 3 Short Example

```ini
[section1]
option11 = value11
option12 = value12
option13 = value13

[section2]
option21 = value21
option22 = value22
```

## Contributors:

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)


## License

This library is licensed under [Apache License 2.0](LICENSE.md)

-------------------------

SPDX-License-Identifier: Apache-2.0
